@@ -1143,3 +1143,24 @@ class DrawAuthentication:
         terms_text.config(state=DISABLED)
 
         terms_root.mainloop()
+
+
+
+def run_authentication(firebase_config_values, call_app):
+    firebaseAuth = FirebaseAuthenticationAPI()
+    firebaseAuth.initialize_firebase(firebase_config_values)
+
+    read_authentication = firebaseAuth.check_authentication()
+    uui, display_name, signed_in = read_authentication
+
+    if not signed_in:
+        login = DrawAuthentication()
+        login.drawLogin()
+
+        if login.authentication_success and login.authentication_email_verified and login.authentication_correct_email_password:
+            uui, display_name, signed_in = firebaseAuth.check_authentication()
+            # Call App Function
+            call_app()
+    else:
+        # Call App Function
+        call_app()
